@@ -1,6 +1,7 @@
 profitMakePointSource=function(xcen,ycen,mag=0,magzero=0,
   modellist=list(sersic=list(mag=0,re=1,nser=0.5,axrat=1,ang=0)),
-  psf=NULL,image=matrix(0,25,25),finesample=1L, add=FALSE, plot=FALSE, ...)
+  psf=NULL,image=matrix(0,25,25),finesample=1L, add=FALSE, plot=FALSE,
+  returnfine=FALSE, ...)
 {
   profitCheckIsPositiveInteger(finesample)
   haspsfimg = !is.null(psf)
@@ -32,8 +33,7 @@ profitMakePointSource=function(xcen,ycen,mag=0,magzero=0,
       modellist[[comp]]$xcen = rep(xcen,length(compmag))
       modellist[[comp]]$ycen = rep(ycen,length(compmag))
     }
-    # Fine sampling is only needed to match image scales - it doesn't make the integral (much) more accurate
-    output = profitMakeModel(modellist,dim=dimimg)$z*scale
+    output = profitMakeModel(modellist,dim=dimimg, finesample=finesample, returnfine = returnfine)$z*scale
   }
   if(add) output=profitAddMats(image,output,pixlocs)
   
